measuretools.fuse_contiguous_measures_in_container_cyclically_by_counts
=======================================================================

.. autofunction:: abjad.tools.measuretools.fuse_contiguous_measures_in_container_cyclically_by_counts.fuse_contiguous_measures_in_container_cyclically_by_counts
